@@ -88,7 +88,7 @@ def find_optimset(diagnostic_headers_file, diagnostic_paths_file, gzip_flag):
                             'search',
                          ]
     #Find the list of center / model with all the months for all the years / experiments and variables requested:
-    #paths_dict=experiment_years.intersection(paths_dict,diag_tree_desc,diag_tree_desc_final)
+    paths_dict=experiment_years.intersection(paths_dict,diag_tree_desc,diag_tree_desc_final)
     
     #Write dictionary to file using JSON encoding. If the gzip flag was used,
     #output directly to a compressed file:
@@ -150,6 +150,23 @@ def tree_retrieval(retrieval_desc,diag_desc,paths_dict):
         print paths_dict
     return
 
+def simulations(simulations_desc):
+    #Reads the file created by find_optimset and gives the path to file:
+    if simulations_desc.in_diagnostic_pointers_file[-3:]=='.gz':
+        infile=gzip.open(simulations_desc.in_diagnostic_pointers_file,'r')
+    else:
+        infile=open(simulations_desc.in_diagnostic_pointers_file,'r')
+    paths_dict=json.load(infile)
+
+    for center in paths_dict['data_pointers'].keys():
+        if center[0]!='_':
+            for model in paths_dict['data_pointers'][center].keys():
+                if model[0]!='_':
+                    for rip in paths_dict['data_pointers'][center][model].keys():
+                        if rip[0]!='_':
+                            print center+','+model+','+rip
+    return
+
 def main():
     import sys
     import argparse 
@@ -216,12 +233,21 @@ def main():
                                  action='store_true',
                                  help='prints only the file_type if selected')
 
+    #Retrieve data
+    simulations_parser=subparsers.add_parser('simulations',
+                                           help='Prints the (center,model,rip) triples available in the pointers file.'
+                                           )
+    simulations_parser.add_argument('in_diagnostic_pointers_file',
+                                 help='Diagnostic headers file with data pointers (input)')
+
     options=parser.parse_args()
 
     if options.command=='optimset':
         find_optimset(options.in_diagnostic_headers_file, options.out_paths_file, options.gzip)
     elif options.command=='retrieve':
         retrieval(options)
+    elif options.command=='simulations':
+        simulations(options)
 
 if __name__ == "__main__":
     main()
